@@ -134,12 +134,12 @@ class ZnTrackParent(ZnTrackType):
             your HEAD Node. You can check the commands in dvc.yaml!
 
         """
+        self.dvc.make_paths()
         self.update_dvc()
+        self.save_internals()
 
         self.write_dvc(force, exec_, always_changed, slurm)
 
-        self.save_internals()
-
     def pre_run(self):
         """Command to be run before run
 
@@ -236,7 +236,14 @@ class ZnTrackParent(ZnTrackType):
                 else:
                     try:
                         if isinstance(new_vals, list):
-                            [getattr(self.dvc, option).append(x) for x in new_vals]
+                            for item in new_vals:
+                                if hasattr(item, "zntrack"):
+                                    if isinstance(item.zntrack, ZnTrackParent):
+                                        getattr(self.dvc, option).append(
+                                            item.zntrack.dvc.json_file
+                                        )
+                                else:
+                                    getattr(self.dvc, option).append(item)
                         else:
                             getattr(self.dvc, option).append(new_vals)
                     except AttributeError:
@@ -444,14 +451,16 @@ class ZnTrackParent(ZnTrackType):
             log.debug(f"un-serialize {self.internals_from_file[self.stage_name]}")
             self.internals = deserializer(self.internals_from_file[self.stage_name])
         except KeyError:
-            log.warning(f"No internals found for {self.stage_name}")
+            log.debug(f"No internals found for {self.stage_name}")
 
     def load_results(self):
         """Load the results from file"""
         try:
             self.results = deserializer(json.loads(self.dvc.json_file.read_text()))
         except FileNotFoundError:
-            log.warning("No results found!")
+            # this can happen when you have a dependency that has not yet been run.
+            #  in that case it should not print the warning and just continue
+            log.debug("No results found!")
 
     @property
     def results(self) -> dict:
@@ -506,6 +515,16 @@ class ZnTrackParent(ZnTrackType):
                 if isinstance(val, ZnTrackStage):
                     # Load the ZnTrackStage
                     self.child.__dict__[key] = val.get()
+                elif isinstance(val, list):
+                    if isinstance(val[0], ZnTrackStage):
+                        # handle DVC.deps([A(load=True), B(load=True), ...])
+                        self.child.__dict__[key] = []
+                        for item in val:
+                            self.child.__dict__[key].append(item.get())
+                    else:
+                        # Don't like the double call here, but I don't know how to
+                        #  avoid it atm.
+                        self.child.__dict__[key] = val
                 else:
                     # Everything except the ZnTrackStage
                     self.child.__dict__[key] = val
