@@ -57,7 +57,7 @@ def conv_class_to_dict(value):
     """
     if hasattr(value, "zntrack"):
         if isinstance(value.zntrack, ZnTrackType):
-            value = {"cls": (value.__module__, value.__class__.__name__)}
+            value = {"cls": (value.zntrack.module, value.__class__.__name__)}
     return value
 
 
